@@ -147,6 +147,16 @@ AFAPI array loadImageNative(const char* filename);
 AFAPI void saveImageNative(const char* filename, const array& in);
 #endif
 
+#if AF_API_VERSION >= 33
+/**
+    Function to check if Image IO is available
+
+    \returns true if ArrayFire was commpiled with ImageIO support, false otherwise.
+    \ingroup imageio_func_available
+*/
+AFAPI bool isImageIOAvailable();
+#endif
+
 /**
     C++ Interface for resizing an image to specified dimensions
 
@@ -211,7 +221,22 @@ AFAPI array rotate(const array& in, const float theta, const bool crop=true, con
 
     \ingroup transform_func_transform
 */
-AFAPI array transform(const array& in, const array& transform, const dim_t odim0 = 0, const dim_t odim1 = 0, const interpType method=AF_INTERP_NEAREST, const bool inverse=true);
+AFAPI array transform(const array& in, const array& transform, const dim_t odim0 = 0, const dim_t odim1 = 0,
+                      const interpType method=AF_INTERP_NEAREST, const bool inverse=true);
+
+#if AF_API_VERSION >= 33
+/**
+    C++ Interface for transforming coordinates
+
+    \param[in] tf is transformation matrix
+    \param[in] d0 is the first input dimension
+    \param[in] d1 is the second input dimension
+    \return the transformed coordinates
+
+    \ingroup transform_func_coordinates
+*/
+AFAPI array transformCoordinates(const array& tf, const float d0, const float d1);
+#endif
 
 /**
     C++ Interface for translating an image
@@ -314,22 +339,6 @@ AFAPI array histogram(const array &in, const unsigned nbins);
 */
 AFAPI array meanShift(const array& in, const float spatial_sigma, const float chromatic_sigma, const unsigned iter, const bool is_color=false);
 
-/**
-    C++ Interface for median filter
-
-    \snippet test/medfilt.cpp ex_image_medfilt
-
-    \param[in]  in array is the input image
-    \param[in]  wind_length is the kernel height
-    \param[in]  wind_width is the kernel width
-    \param[in]  edge_pad value will decide what happens to border when running
-                filter in their neighborhood. It takes one of the values [\ref AF_PAD_ZERO | \ref AF_PAD_SYM]
-    \return     the processed image
-
-    \ingroup image_func_medfilt
-*/
-AFAPI array medfilt(const array& in, const dim_t wind_length = 3, const dim_t wind_width = 3, const borderType edge_pad = AF_PAD_ZERO);
-
 /**
     C++ Interface for minimum filter
 
@@ -652,6 +661,33 @@ AFAPI array ycbcr2rgb(const array& in, const YCCStd standard=AF_YCC_601);
 AFAPI array rgb2ycbcr(const array& in, const YCCStd standard=AF_YCC_601);
 #endif
 
+#if AF_API_VERSION >= 34
+/**
+   C++ Interface for calculating an image moment
+
+   \param[out] out is a pointer to a pre-allocated array where the calculated moment(s) will be placed.
+   User is responsible for ensuring enough space to hold all requested moments
+   \param[in]  in is the input image
+   \param[in] moment is moment(s) to calculate
+
+   \ingroup image_func_moments
+ */
+AFAPI void moments(double* out, const array& in, const momentType moment=AF_MOMENT_FIRST_ORDER);
+#endif
+
+#if AF_API_VERSION >= 34
+/**
+   C++ Interface for calculating image moments
+
+   \param[in]  in contains the input image(s)
+   \param[in] moment is moment(s) to calculate
+   \return array containing the requested moment of each image
+
+   \ingroup image_func_moments
+ */
+AFAPI array moments(const array& in, const momentType moment=AF_MOMENT_FIRST_ORDER);
+#endif
+
 }
 #endif
 
@@ -794,6 +830,20 @@ extern "C" {
     AFAPI af_err af_save_image_native(const char* filename, const af_array in);
 #endif
 
+#if AF_API_VERSION >= 33
+    /**
+        Function to check if Image IO is available
+
+        \param[out] out is true if ArrayFire was commpiled with ImageIO support,
+        false otherwise.
+
+        \return     \ref AF_SUCCESS if successful
+
+        \ingroup imageio_func_available
+    */
+    AFAPI af_err af_is_image_io_available(bool *out);
+#endif
+
     /**
        C Interface for resizing an image to specified dimensions
 
@@ -829,6 +879,21 @@ extern "C" {
                               const dim_t odim0, const dim_t odim1,
                               const af_interp_type method, const bool inverse);
 
+#if AF_API_VERSION >= 33
+    /**
+       C Interface for transforming an image
+       C++ Interface for transforming coordinates
+
+       \param[out] out the transformed coordinates
+       \param[in] tf is transformation matrix
+       \param[in] d0 is the first input dimension
+       \param[in] d1 is the second input dimension
+
+       \ingroup transform_func_coordinates
+    */
+    AFAPI af_err af_transform_coordinates(af_array *out, const af_array tf, const float d0, const float d1);
+#endif
+
     /**
        C Interface for rotating an image
 
@@ -1000,22 +1065,6 @@ extern "C" {
     */
     AFAPI af_err af_mean_shift(af_array *out, const af_array in, const float spatial_sigma, const float chromatic_sigma, const unsigned iter, const bool is_color);
 
-    /**
-        C Interface for median filter
-
-        \param[out] out array is the processed image
-        \param[in]  in array is the input image
-        \param[in]  wind_length is the kernel height
-        \param[in]  wind_width is the kernel width
-        \param[in]  edge_pad value will decide what happens to border when running
-                    filter in their neighborhood. It takes one of the values [\ref AF_PAD_ZERO | \ref AF_PAD_SYM]
-        \return     \ref AF_SUCCESS if the median filter is applied successfully,
-        otherwise an appropriate error code is returned.
-
-        \ingroup image_func_medfilt
-    */
-    AFAPI af_err af_medfilt(af_array *out, const af_array in, const dim_t wind_length, const dim_t wind_width, const af_border_type edge_pad);
-
     /**
         C Interface for minimum filter
 
@@ -1294,6 +1343,38 @@ extern "C" {
     */
     AFAPI af_err af_rgb2ycbcr(af_array* out, const af_array in, const af_ycc_std standard);
 #endif
+
+#if AF_API_VERSION >= 34
+    /**
+       C Interface for finding image moments
+
+       \param[out] out is an array containing the calculated moments
+       \param[in]  in is an array of image(s)
+       \param[in] moment is moment(s) to calculate
+       \return     ref AF_SUCCESS if the moment calculation is successful,
+       otherwise an appropriate error code is returned.
+
+       \ingroup image_func_moments
+    */
+    AFAPI af_err af_moments(af_array *out, const af_array in, const af_moment_type moment);
+#endif
+
+#if AF_API_VERSION >= 34
+    /**
+       C Interface for calculating image moment(s) of a single image
+
+       \param[out] out is a pointer to a pre-allocated array where the calculated moment(s) will be placed.
+       User is responsible for ensuring enough space to hold all requested moments
+       \param[in] in is the input image
+       \param[in] moment is moment(s) to calculate
+       \return     ref AF_SUCCESS if the moment calculation is successful,
+       otherwise an appropriate error code is returned.
+
+       \ingroup image_func_moments
+    */
+    AFAPI af_err af_moments_all(double* out, const af_array in, const af_moment_type moment);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
