@@ -1,6 +1,7 @@
 var group__arrayfire__func =
 [
     [ "DoG", "group__cv__func__dog.htm", "group__cv__func__dog" ],
+    [ "Random Number Generation", "group__random__mat.htm", "group__random__mat" ],
     [ "SAT", "group__image__func__sat.htm", "group__image__func__sat" ],
     [ "abs", "group__arith__func__abs.htm", "group__arith__func__abs" ],
     [ "accum", "group__scan__func__accum.htm", "group__scan__func__accum" ],
@@ -46,6 +47,7 @@ var group__arrayfire__func =
     [ "count", "group__reduce__func__count.htm", "group__reduce__func__count" ],
     [ "cov", "group__stat__func__cov.htm", "group__stat__func__cov" ],
     [ "deleteImageMem", "group__imagemem__func__delete.htm", "group__imagemem__func__delete" ],
+    [ "dense", "group__sparse__func__dense.htm", "group__sparse__func__dense" ],
     [ "det", "group__lapack__ops__func__det.htm", "group__lapack__ops__func__det" ],
     [ "deviceInfo", "group__device__func__prop.htm", "group__device__func__prop" ],
     [ "deviceMemInfo", "group__device__func__mem.htm", "group__device__func__mem" ],
@@ -86,10 +88,11 @@ var group__arrayfire__func =
     [ "getAvailableBackends", "group__unified__func__getavailbackends.htm", "group__unified__func__getavailbackends" ],
     [ "getBackendCount", "group__unified__func__getbackendcount.htm", "group__unified__func__getbackendcount" ],
     [ "getBackendId", "group__unified__func__getbackendid.htm", "group__unified__func__getbackendid" ],
+    [ "getDefaultRandomEngine", "group__random__func__get__default__engine.htm", "group__random__func__get__default__engine" ],
     [ "getDevice", "group__device__func__get.htm", "group__device__func__get" ],
     [ "getDeviceCount", "group__device__func__count.htm", "group__device__func__count" ],
     [ "getDeviceId", "group__unified__func__getdeviceid.htm", "group__unified__func__getdeviceid" ],
-    [ "getSeed", "group__data__func__getseed.htm", "group__data__func__getseed" ],
+    [ "getSeed", "group__random__func__get__seed.htm", "group__random__func__get__seed" ],
     [ "gloh", "group__cv__func__gloh.htm", null ],
     [ "grad", "group__calc__func__grad.htm", "group__calc__func__grad" ],
     [ "gray2rgb", "group__image__func__gray2rgb.htm", "group__image__func__gray2rgb" ],
@@ -138,11 +141,12 @@ var group__arrayfire__func =
     [ "meanshift", "group__image__func__mean__shift.htm", "group__image__func__mean__shift" ],
     [ "medfilt", "group__image__func__medfilt.htm", "group__image__func__medfilt" ],
     [ "median", "group__stat__func__median.htm", "group__stat__func__median" ],
-    [ "min", "group__reduce__func__min.htm", "group__reduce__func__min" ],
     [ "min", "group__arith__func__min.htm", "group__arith__func__min" ],
+    [ "min", "group__reduce__func__min.htm", "group__reduce__func__min" ],
     [ "minfilt", "group__image__func__minfilt.htm", "group__image__func__minfilt" ],
     [ "mod", "group__arith__func__mod.htm", "group__arith__func__mod" ],
     [ "moddims", "group__manip__func__moddims.htm", "group__manip__func__moddims" ],
+    [ "moments", "group__image__func__moments.htm", "group__image__func__moments" ],
     [ "mul", "group__arith__func__mul.htm", "group__arith__func__mul" ],
     [ "nearestNeighbour", "group__cv__func__nearest__neighbour.htm", "group__cv__func__nearest__neighbour" ],
     [ "neg", "group__arith__func__neg.htm", "group__arith__func__neg" ],
@@ -162,8 +166,10 @@ var group__arrayfire__func =
     [ "print", "group__print__func__print.htm", "group__print__func__print" ],
     [ "product", "group__reduce__func__product.htm", "group__reduce__func__product" ],
     [ "qr", "group__lapack__factor__func__qr.htm", "group__lapack__factor__func__qr" ],
-    [ "randn", "group__data__func__randn.htm", "group__data__func__randn" ],
-    [ "randu", "group__data__func__randu.htm", "group__data__func__randu" ],
+    [ "randn", "group__random__func__randn.htm", "group__random__func__randn" ],
+    [ "randomEngine", "group__random__engine__class.htm", "group__random__engine__class" ],
+    [ "randomEngine Constructors", "group__random__engine__func__constructor.htm", "group__random__engine__func__constructor" ],
+    [ "randu", "group__random__func__randu.htm", "group__random__func__randu" ],
     [ "range", "group__data__func__range.htm", "group__data__func__range" ],
     [ "rank", "group__lapack__ops__func__rank.htm", "group__lapack__ops__func__rank" ],
     [ "readArray", "group__stream__func__read.htm", "group__stream__func__read" ],
@@ -184,10 +190,13 @@ var group__arrayfire__func =
     [ "saveImage", "group__imageio__func__save.htm", "group__imageio__func__save" ],
     [ "saveImageMem", "group__imagemem__func__save.htm", "group__imagemem__func__save" ],
     [ "scale", "group__transform__func__scale.htm", "group__transform__func__scale" ],
+    [ "scan", "group__scan__func__scan.htm", "group__scan__func__scan" ],
+    [ "scanByKey", "group__scan__func__scanbykey.htm", "group__scan__func__scanbykey" ],
     [ "select", "group__data__func__select.htm", "group__data__func__select" ],
     [ "setBackend", "group__unified__func__setbackend.htm", "group__unified__func__setbackend" ],
+    [ "setDefaultRandomEngineType", "group__random__func__set__type.htm", "group__random__func__set__type" ],
     [ "setDevice", "group__device__func__set.htm", "group__device__func__set" ],
-    [ "setSeed", "group__data__func__setseed.htm", "group__data__func__setseed" ],
+    [ "setSeed", "group__random__func__set__seed.htm", "group__random__func__set__seed" ],
     [ "setintersect", "group__set__func__intersect.htm", "group__set__func__intersect" ],
     [ "setunion", "group__set__func__union.htm", "group__set__func__union" ],
     [ "setunique", "group__set__func__unique.htm", "group__set__func__unique" ],
@@ -204,6 +213,14 @@ var group__arrayfire__func =
     [ "sort", "group__sort__func__sort.htm", "group__sort__func__sort" ],
     [ "sortByKey", "group__sort__func__sort__keys.htm", "group__sort__func__sort__keys" ],
     [ "sortIndex", "group__sort__func__sort__index.htm", "group__sort__func__sort__index" ],
+    [ "sparse", "group__sparse__func__create.htm", "group__sparse__func__create" ],
+    [ "sparseConvertTo", "group__sparse__func__convert__to.htm", "group__sparse__func__convert__to" ],
+    [ "sparseGetColdx", "group__sparse__func__col__idx.htm", "group__sparse__func__col__idx" ],
+    [ "sparseGetInfo", "group__sparse__func__info.htm", "group__sparse__func__info" ],
+    [ "sparseGetNNZ", "group__sparse__func__nnz.htm", "group__sparse__func__nnz" ],
+    [ "sparseGetRowIdx", "group__sparse__func__row__idx.htm", "group__sparse__func__row__idx" ],
+    [ "sparseGetStorage", "group__sparse__func__storage.htm", "group__sparse__func__storage" ],
+    [ "sparseGetValues", "group__sparse__func__values.htm", "group__sparse__func__values" ],
     [ "sqrt", "group__arith__func__sqrt.htm", "group__arith__func__sqrt" ],
     [ "stdev", "group__stat__func__stdev.htm", "group__stat__func__stdev" ],
     [ "sub", "group__arith__func__sub.htm", "group__arith__func__sub" ],
@@ -223,7 +240,7 @@ var group__arrayfire__func =
     [ "trunc", "group__arith__func__trunc.htm", "group__arith__func__trunc" ],
     [ "unwrap", "group__image__func__unwrap.htm", "group__image__func__unwrap" ],
     [ "upper", "group__data__func__upper.htm", "group__data__func__upper" ],
-    [ "util", "group__index__func__util.htm", "group__index__func__util" ],
+    [ "util", "group__index__func__util.htm", null ],
     [ "var", "group__stat__func__var.htm", "group__stat__func__var" ],
     [ "where", "group__scan__func__where.htm", "group__scan__func__where" ],
     [ "wrap", "group__image__func__wrap.htm", "group__image__func__wrap" ],
